@@ -44,8 +44,17 @@ sub _prepare {
     my $listen = shift @{$self->{listen}};
 
     my $sock;
-    if ($listen =~ m#^unix/#) {
-        croak "listening on a unix socket isn't supported yet";
+    if ($listen =~ m#^/\w#) {
+        require IO::Socket::UNIX;
+        unlink $listen if -S $listen;
+        my $saved = umask(0);
+        $sock = IO::Socket::UNIX->new(
+           Local => $listen,
+           Listen => SOMAXCONN,
+        );
+        umask($saved);
+        croak "couldn't bind to socket: $!" unless $sock;
+        $sock->blocking(0) || croak "couldn't unblock socket: $!";
     }
     else {
         require IO::Socket::INET;
